@@ -33,14 +33,14 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
     def delete_record(self, indexes_keys_selectors: dict) -> bool:
         def middleware(indexes_keys: dict) -> bool:
             return self.dynamodb_client.delete_record(indexes_keys_selectors=indexes_keys)
-        return self._record_deletion(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
+        return self._delete_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
 
-    def remove_record(self, indexes_keys_selectors: dict) -> Optional[dict]:
+    def remove_record(self, indexes_keys_selectors: dict, data_validation: bool = True) -> Optional[dict]:
         def middleware(indexes_keys: dict) -> Optional[dict]:
             return self.dynamodb_client.remove_record(indexes_keys_selectors=indexes_keys)
-        return self._record_deletion(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
+        return self._remove_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors, data_validation=data_validation)
 
-    def get_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, index_name: Optional[str] = None) -> Any:
+    def get_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, index_name: Optional[str] = None, data_validation: bool = True) -> Any:
         def middleware(field_path_elements: List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], has_multiple_fields_path: bool):
             if has_multiple_fields_path is not True:
                 field_path_elements: List[DatabasePathElement]
@@ -56,20 +56,20 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
                     key_value=key_value, fields_path_elements=field_path_elements
                 )
                 return response_data
-        return self._get_field(middleware=middleware, field_path=field_path, query_kwargs=query_kwargs)
+        return self._get_field(middleware=middleware, field_path=field_path, query_kwargs=query_kwargs, data_validation=data_validation)
 
-    def get_multiple_fields(self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None) -> Optional[dict]:
+    def get_multiple_fields(self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None, data_validation: bool = True) -> Optional[dict]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self.dynamodb_client.get_or_query_single_item(
                 index_name=index_name or self.primary_index_name,
                 key_value=key_value, fields_path_elements=fields_path_elements,
             )
-        return self._get_multiple_fields(middleware=middleware, getters=getters)
+        return self._get_multiple_fields(middleware=middleware, getters=getters, data_validation=data_validation)
 
 
     def query_field(
             self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, index_name: Optional[str] = None,
-            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
+            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, data_validation: bool = True, **additional_kwargs
     ) -> Optional[dict]:
         def middleware(field_path_elements: List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], has_multiple_fields_path: bool) -> List[dict]:
             return self.dynamodb_client.query_items_by_key(
@@ -79,11 +79,14 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
                 query_limit=records_query_limit, filter_expression=filter_expression,
                 **additional_kwargs
             )
-        return self._query_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs, index_name=index_name)
+        return self._query_field(
+            middleware=middleware, key_value=key_value, field_path=field_path,
+            query_kwargs=query_kwargs, index_name=index_name, data_validation=data_validation
+        )
 
     def query_multiple_fields(
             self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None,
-            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
+            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, data_validation: bool = True, **additional_kwargs
     ) -> Optional[Dict[str, dict]]:
         def middleware(fields_path_elements: Dict[str, List[DatabasePathElement]], _) -> List[dict]:
             return self.dynamodb_client.query_items_by_key(
@@ -92,7 +95,10 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
                 query_limit=records_query_limit, filter_expression=filter_expression,
                 **additional_kwargs
             )
-        return self._query_multiple_fields(middleware=middleware, key_value=key_value, getters=getters, index_name=index_name)
+        return self._query_multiple_fields(
+            middleware=middleware, key_value=key_value, getters=getters,
+            index_name=index_name, data_validation=data_validation
+        )
 
     def lightweight_query_multiple_fields(
             self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None,
@@ -130,10 +136,13 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
                 key_value=key_value, value=validated_data,
                 field_path_elements=field_path_elements
             )
-            return True if response is not None else False
+            return response is not None
         return self._update_field(middleware=middleware, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
 
-    def update_field_return_old(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> Tuple[bool, Optional[Any]]:
+    def update_field_return_old(
+            self, key_value: str, field_path: str, value_to_set: Any,
+            query_kwargs: Optional[dict] = None, data_validation: bool = True
+    ) -> Tuple[bool, Optional[Any]]:
         def middleware(field_path_elements: List[DatabasePathElement], validated_data: Any) -> Tuple[bool, Optional[dict]]:
             response: Optional[Response] = self.dynamodb_client.set_update_data_element_to_map_with_default_initialization(
                 index_name=self.primary_index_name,
@@ -144,12 +153,15 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
             if response is None:
                 return False, None
 
-            response_attributes: Optional[dict] = (
+            python_response_attributes: Optional[dict] = (
                 DynamoDBUtils.dynamodb_to_python_higher_level(response.attributes)
                 if response.attributes is not None else None
             )
-            return True, response_attributes
-        return self._update_field_return_old(middleware=middleware, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
+            return True, python_response_attributes
+        return self._update_field_return_old(
+            middleware=middleware, field_path=field_path, value_to_set=value_to_set,
+            query_kwargs=query_kwargs, data_validation=data_validation
+        )
 
     def update_multiple_fields(self, key_value: str, setters: List[FieldSetter or UnsafeFieldSetter]) -> bool:
         def middleware(dynamodb_setters: List[FieldPathSetter]) -> bool:
@@ -160,7 +172,7 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
             return response is not None
         return self._update_multiple_fields(middleware=middleware, setters=setters)
 
-    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter]) -> Tuple[bool, Dict[str, Optional[Any]]]:
+    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter], data_validation: bool = True) -> Tuple[bool, Dict[str, Optional[Any]]]:
         def middleware(dynamodb_setters: Dict[str, FieldPathSetter]) -> Tuple[bool, Optional[dict]]:
             response: Optional[Response] = self.dynamodb_client.set_update_multiple_data_elements_to_map(
                 index_name=self.primary_index_name, key_value=key_value,
@@ -174,33 +186,35 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
                 if response.attributes is not None else None
             )
             return True, python_response_attributes
-        return self._update_multiple_fields_return_old(middleware=middleware, setters=setters)
+        return self._update_multiple_fields_return_old(middleware=middleware, setters=setters, data_validation=data_validation)
 
-    def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> Optional[Any]:
-        def middleware(fields_path_elements: List[List[DatabasePathElement]]):
+    def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, data_validation: bool = True) -> Optional[Any]:
+        def middleware(fields_path_elements: List[List[DatabasePathElement]]) -> Optional[Dict[str, Any]]:
             return self.dynamodb_client.remove_data_elements_from_map(
                 index_name=self.primary_index_name,
                 key_value=key_value, targets_path_elements=fields_path_elements,
                 retrieve_removed_elements=True
             )
-        return self._remove_field(middleware=middleware, field_path=field_path, query_kwargs=query_kwargs)
+        return self._remove_field(middleware=middleware, field_path=field_path, query_kwargs=query_kwargs, data_validation=data_validation)
 
-    def remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Dict[str, Any]:
+    def remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover], data_validation: bool = True) -> Dict[str, Optional[Any]]:
         def task_executor(remover_item: FieldRemover):
             return self.remove_field(
                 key_value=key_value,
                 field_path=remover_item.field_path,
-                query_kwargs=remover_item.query_kwargs
+                query_kwargs=remover_item.query_kwargs,
+                data_validation=data_validation
             )
         return self._async_field_removers_executor(task_executor=task_executor, removers=removers)
 
     def delete_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> bool:
-        def middleware(fields_path_elements: List[List[DatabasePathElement]]):
-            return self.dynamodb_client.remove_data_elements_from_map(
+        def middleware(fields_path_elements: List[List[DatabasePathElement]]) -> bool:
+            removed_items = self.dynamodb_client.remove_data_elements_from_map(
                 index_name=self.primary_index_name,
                 key_value=key_value, targets_path_elements=fields_path_elements,
                 retrieve_removed_elements=False
             )
+            return removed_items is not None
         return self._delete_field(middleware=middleware, field_path=field_path, query_kwargs=query_kwargs)
 
     def delete_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Dict[str, bool]:
@@ -212,14 +226,14 @@ class DynamoDBBasicTable(BaseBasicTable, DynamoDBLowLevelTableOperations):
             )
         return self._async_field_removers_executor(task_executor=task_executor, removers=removers)
 
-    def grouped_remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Optional[Dict[str, Any]]:
+    def grouped_remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover], data_validation: bool = True) -> Optional[Dict[str, Any]]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self.dynamodb_client.remove_data_elements_from_map(
                 index_name=self.primary_index_name,
                 key_value=key_value, targets_path_elements=fields_path_elements,
                 retrieve_removed_elements=True
             )
-        return self._grouped_remove_multiple_fields(middleware=middleware, removers=removers)
+        return self._grouped_remove_multiple_fields(middleware=middleware, removers=removers, data_validation=data_validation)
 
     def grouped_delete_multiple_fields(self, key_value: str, removers: List[FieldRemover]) -> bool:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
