@@ -62,14 +62,14 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
             return self.dynamodb_client.delete_record(indexes_keys_selectors=indexes_keys)
         return self._delete_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
 
-    def remove_record(self, indexes_keys_selectors: dict) -> Optional[dict]:
+    def remove_record(self, indexes_keys_selectors: dict, data_validation: bool = True) -> Optional[dict]:
         def middleware(indexes_keys: dict) -> Optional[dict]:
             return self.dynamodb_client.remove_record(indexes_keys_selectors=indexes_keys)
-        return self._remove_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
+        return self._remove_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors, data_validation=data_validation)
 
     def query_field(
             self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, index_name: Optional[str] = None,
-            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
+            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, data_validation: bool = True, **additional_kwargs
     ) -> Optional[dict]:
         def middleware(field_path_elements: List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], has_multiple_fields_path: bool) -> List[dict]:
             return self.dynamodb_client.query_items_by_key(
@@ -79,11 +79,14 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
                 query_limit=records_query_limit, filter_expression=filter_expression,
                 **additional_kwargs
             )
-        return self._query_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs, index_name=index_name)
+        return self._query_field(
+            middleware=middleware, key_value=key_value, field_path=field_path,
+            query_kwargs=query_kwargs, index_name=index_name, data_validation=data_validation
+        )
 
     def query_multiple_fields(
             self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None,
-            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
+            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, data_validation: bool = True, **additional_kwargs
     ):
         def middleware(fields_path_elements: Dict[str, List[DatabasePathElement]], _) -> List[dict]:
             return self.dynamodb_client.query_items_by_key(
@@ -93,9 +96,12 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
                 query_limit=records_query_limit, filter_expression=filter_expression,
                 **additional_kwargs
             )
-        return self._query_multiple_fields(middleware=middleware, key_value=key_value, getters=getters, index_name=index_name)
+        return self._query_multiple_fields(
+            middleware=middleware, key_value=key_value, getters=getters,
+            index_name=index_name, data_validation=data_validation
+        )
 
-    def get_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> Any:
+    def get_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, data_validation: bool = True) -> Any:
         def middleware(field_path_elements: List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], has_multiple_fields_path: bool):
             if has_multiple_fields_path is not True:
                 field_path_elements: List[DatabasePathElement]
@@ -109,20 +115,23 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
                     index_name=self.primary_index_name,
                     key_value=key_value, fields_path_elements=field_path_elements,
                 )
-        return self._get_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs)
+        return self._get_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs, data_validation=data_validation)
 
-    def get_multiple_fields(self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None) -> Optional[dict]:
+    def get_multiple_fields(self, key_value: str, getters: Dict[str, FieldGetter], index_name: Optional[str] = None, data_validation: bool = True) -> Optional[dict]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self.dynamodb_client.get_or_query_single_item(
                 index_name=index_name or self.primary_index_name,
                 key_value=key_value, fields_path_elements=fields_path_elements,
             )
-        return self._get_multiple_fields(middleware=middleware, key_value=key_value, getters=getters)
+        return self._get_multiple_fields(middleware=middleware, key_value=key_value, getters=getters, data_validation=data_validation)
 
     def update_field(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> bool:
         return self._update_field(key_value=key_value, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
 
-    def update_field_return_old(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> Tuple[bool, Optional[Any]]:
+    def update_field_return_old(
+            self, key_value: str, field_path: str, value_to_set: Any,
+            query_kwargs: Optional[dict] = None, data_validation: bool = True
+    ) -> Tuple[bool, Optional[Any]]:
         def middleware(field_path_elements: List[DatabasePathElement], validated_data: Any):
             response: Optional[Response] = self.dynamodb_client.set_update_data_element_to_map_with_default_initialization(
                 index_name=self.primary_index_name,
@@ -138,12 +147,15 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
                 if response.attributes is not None else None
             )
             return True, python_response_attributes
-        return self._update_field_return_old(middleware=middleware, key_value=key_value, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
+        return self._update_field_return_old(
+            middleware=middleware, key_value=key_value, field_path=field_path, value_to_set=value_to_set,
+            query_kwargs=query_kwargs, data_validation=data_validation
+        )
 
     def update_multiple_fields(self, key_value: str, setters: List[FieldSetter or UnsafeFieldSetter]) -> bool:
         return self._update_multiple_fields(key_value=key_value, setters=setters)
 
-    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter]) -> Tuple[bool, Dict[str, Optional[Any]]]:
+    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter], data_validation: bool = True) -> Tuple[bool, Dict[str, Optional[Any]]]:
         def middleware(dynamodb_setters: Dict[str, FieldPathSetter]) -> Tuple[bool, Optional[dict]]:
             response: Optional[Response] = self.dynamodb_client.set_update_multiple_data_elements_to_map(
                 index_name=self.primary_index_name, key_value=key_value,
@@ -157,23 +169,24 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
                 if response.attributes is not None else None
             )
             return True, python_response_attributes
-        return self._update_multiple_fields_return_old(middleware=middleware, key_value=key_value, setters=setters)
+        return self._update_multiple_fields_return_old(middleware=middleware, key_value=key_value, setters=setters, data_validation=data_validation)
 
-    def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> Optional[Any]:
+    def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, data_validation: bool = True) -> Optional[Any]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self.dynamodb_client.remove_data_elements_from_map(
                 index_name=self.primary_index_name,
                 key_value=key_value, targets_path_elements=fields_path_elements,
                 retrieve_removed_elements=True
             )
-        return self._remove_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs)
+        return self._remove_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs, data_validation=data_validation)
 
-    def remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Optional[Dict[str, Any]]:
+    def remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover], data_validation: bool = True) -> Dict[str, Optional[Any]]:
         def task_executor(remover_item: FieldRemover):
             return self.remove_field(
                 key_value=key_value,
                 field_path=remover_item.field_path,
-                query_kwargs=remover_item.query_kwargs
+                query_kwargs=remover_item.query_kwargs,
+                data_validation=data_validation
             )
         return self._async_field_removers_executor(task_executor=task_executor, removers=removers)
 
@@ -189,14 +202,14 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
             )
         return self._async_field_removers_executor(task_executor=task_executor, removers=removers)
 
-    def grouped_remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Optional[Dict[str, Any]]:
+    def grouped_remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover], data_validation: bool = True) -> Optional[Dict[str, Any]]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self.dynamodb_client.remove_data_elements_from_map(
                 index_name=self.primary_index_name,
                 key_value=key_value, targets_path_elements=fields_path_elements,
                 retrieve_removed_elements=True
              )
-        return self._grouped_remove_multiple_fields(middleware=middleware, key_value=key_value, removers=removers)
+        return self._grouped_remove_multiple_fields(middleware=middleware, key_value=key_value, removers=removers, data_validation=data_validation)
 
     def grouped_delete_multiple_fields(self, key_value: str, removers: List[FieldRemover]) -> bool:
         return self._grouped_delete_multiple_fields(key_value=key_value, removers=removers)
