@@ -50,14 +50,14 @@ class InoftVocalEngineCachingTable(BaseCachingTable, InoftVocalEngineTableConnec
             return self._delete_record_request(indexes_keys_selectors=indexes_keys)
         return self._delete_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
 
-    def remove_record(self, indexes_keys_selectors: dict) -> Optional[dict]:
+    def remove_record(self, indexes_keys_selectors: dict, data_validation: bool = True) -> Optional[dict]:
         def middleware(indexes_keys: dict) -> Optional[dict]:
             return self._remove_record_request(indexes_keys_selectors=indexes_keys)
-        return self._remove_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
+        return self._remove_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors, data_validation=data_validation)
 
     def query_field(
-            self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None,
-            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
+            self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, records_query_limit: Optional[int] = None,
+            filter_expression: Optional[Any] = None, data_validation: bool = True, **additional_kwargs
     ) -> Optional[dict]:
         def middleware(field_path_elements: List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], has_multiple_fields_path: bool) -> List[dict]:
             return self._query_items_by_key(
@@ -66,20 +66,26 @@ class InoftVocalEngineCachingTable(BaseCachingTable, InoftVocalEngineTableConnec
                 query_limit=records_query_limit, filter_expression=filter_expression,
                 **additional_kwargs
             )
-        return self._query_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs)
+        return self._query_field(
+            middleware=middleware, key_value=key_value, field_path=field_path,
+            query_kwargs=query_kwargs, index_name=None, data_validation=data_validation
+        )
 
     def query_multiple_fields(
-            self, key_value: str, getters: Dict[str, FieldGetter],
-            records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
+            self, key_value: str, getters: Dict[str, FieldGetter], records_query_limit: Optional[int] = None,
+            filter_expression: Optional[Any] = None, data_validation: bool = True, **additional_kwargs
     ):
         def middleware(fields_path_elements: Dict[str, List[DatabasePathElement]], _) -> List[dict]:
             return self._query_items_by_key(
                 key_value=key_value, field_path_elements=fields_path_elements, has_multiple_fields_path=True,
                 query_limit=records_query_limit, filter_expression=filter_expression, **additional_kwargs
             )
-        return self._query_multiple_fields(middleware=middleware, key_value=key_value, getters=getters)
+        return self._query_multiple_fields(
+            middleware=middleware, key_value=key_value, getters=getters,
+            index_name=None, data_validation=data_validation
+        )
 
-    def get_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> Any:
+    def get_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, data_validation: bool = True) -> Any:
         def middleware(field_path_elements: List[DatabasePathElement] or Dict[str, List[DatabasePathElement]], has_multiple_fields_path: bool):
             if has_multiple_fields_path is not True:
                 field_path_elements: List[DatabasePathElement]
@@ -87,45 +93,56 @@ class InoftVocalEngineCachingTable(BaseCachingTable, InoftVocalEngineTableConnec
             else:
                 field_path_elements: Dict[str, List[DatabasePathElement]]
                 return self._get_values_in_multiple_path_target(key_value=key_value, fields_path_elements=field_path_elements)
-        return self._get_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs)
+        return self._get_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs, data_validation=data_validation)
 
-    def get_multiple_fields(self, key_value: str, getters: Dict[str, FieldGetter]) -> Optional[dict]:
+    def get_multiple_fields(self, key_value: str, getters: Dict[str, FieldGetter], data_validation: bool = True) -> Optional[dict]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self._get_or_query_single_item(key_value=key_value, fields_path_elements=fields_path_elements)
-        return self._get_multiple_fields(middleware=middleware, key_value=key_value, getters=getters)
+        return self._get_multiple_fields(middleware=middleware, key_value=key_value, getters=getters, data_validation=data_validation)
 
     def update_field(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> bool:
         return self._update_field(key_value=key_value, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
 
-    def update_field_return_old(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> Tuple[bool, Optional[Any]]:
+    def update_field_return_old(
+            self, key_value: str, field_path: str, value_to_set: Any,
+            query_kwargs: Optional[dict] = None, data_validation: bool = True
+    ) -> Tuple[bool, Optional[Any]]:
         def middleware(field_path_elements: List[DatabasePathElement], validated_data: Any) -> Tuple[bool, Optional[Any]]:
             update_success, response_attributes = self._set_update_data_element_to_map_with_default_initialization_return_old(
                 key_value=key_value, value=validated_data,
                 field_path_elements=field_path_elements
             )
             return update_success, response_attributes
-        return self._update_field_return_old(middleware=middleware, key_value=key_value, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
+        return self._update_field_return_old(
+            middleware=middleware, key_value=key_value, field_path=field_path, value_to_set=value_to_set,
+            query_kwargs=query_kwargs, data_validation=data_validation
+        )
 
     def update_multiple_fields(self, key_value: str, setters: List[FieldSetter or UnsafeFieldSetter]) -> bool:
         return self._update_multiple_fields(key_value=key_value, setters=setters)
 
-    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter]) -> Tuple[bool, Dict[str, Optional[Any]]]:
+    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter], data_validation: bool = True) -> Tuple[bool, Dict[str, Optional[Any]]]:
         def middleware(dynamodb_setters: Dict[str, FieldPathSetter]) -> Tuple[bool, dict]:
             update_success, response_attributes = self._set_update_multiple_data_elements_to_map_return_old(
                 key_value=key_value, setters=list(dynamodb_setters.values())
             )
             return update_success, response_attributes
-        return self._update_multiple_fields_return_old(middleware=middleware, key_value=key_value, setters=setters)
+        return self._update_multiple_fields_return_old(middleware=middleware, key_value=key_value, setters=setters, data_validation=data_validation)
 
-    def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> Optional[Any]:
+    def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, data_validation: bool = True) -> Optional[Any]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self._remove_data_elements_from_map(key_value=key_value, fields_path_elements=fields_path_elements)
-        return self._remove_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs)
+        return self._remove_field(middleware=middleware, key_value=key_value, field_path=field_path, query_kwargs=query_kwargs, data_validation=data_validation)
 
-    def remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Optional[Dict[str, Any]]:
-        return {key: self.remove_field(
-            key_value=key_value, field_path=item.field_path, query_kwargs=item.query_kwargs
-        ) for key, item in removers.items()}
+    def remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover], data_validation: bool = True) -> Dict[str, Optional[Any]]:
+        def task_executor(remover_item: FieldRemover):
+            return self.remove_field(
+                key_value=key_value,
+                field_path=remover_item.field_path,
+                query_kwargs=remover_item.query_kwargs,
+                data_validation=data_validation
+            )
+        return self._async_field_removers_executor(task_executor=task_executor, removers=removers)
 
     def delete_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> bool:
         return self._delete_field(key_value=key_value, field_path=field_path, query_kwargs=query_kwargs)
@@ -139,12 +156,12 @@ class InoftVocalEngineCachingTable(BaseCachingTable, InoftVocalEngineTableConnec
             )
         return self._async_field_removers_executor(task_executor=task_executor, removers=removers)
 
-    def grouped_remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover]) -> Optional[Dict[str, Any]]:
+    def grouped_remove_multiple_fields(self, key_value: str, removers: Dict[str, FieldRemover], data_validation: bool = True) -> Optional[Dict[str, Any]]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self._remove_data_elements_from_map(
                 key_value=key_value, fields_path_elements=fields_path_elements
             )
-        return self._grouped_remove_multiple_fields(middleware=middleware, key_value=key_value, removers=removers)
+        return self._grouped_remove_multiple_fields(middleware=middleware, key_value=key_value, removers=removers, data_validation=data_validation)
 
     def grouped_delete_multiple_fields(self, key_value: str, removers: List[FieldRemover]) -> bool:
         return self._grouped_delete_multiple_fields(key_value=key_value, removers=removers)
